@@ -21,6 +21,7 @@
 
 import os
 import tempfile
+from pathlib import Path
 from unittest.mock import Mock
 
 from synapse.config import ConfigError
@@ -309,7 +310,9 @@ class MasAuthDelegation(TestCase):
     def test_secret_and_secret_path_are_mutually_exclusive(self) -> None:
         with tempfile.NamedTemporaryFile() as f:
             self.config_dict["matrix_authentication_service"]["secret"] = "verysecret"
-            self.config_dict["matrix_authentication_service"]["secret_path"] = f.name
+            self.config_dict["matrix_authentication_service"]["secret_path"] = Path(
+                f.name
+            )
             with self.assertRaises(ConfigError):
                 self.parse_config()
 
@@ -317,13 +320,15 @@ class MasAuthDelegation(TestCase):
         with tempfile.NamedTemporaryFile(buffering=0) as f:
             f.write(b"53C237")
             del self.config_dict["matrix_authentication_service"]["secret"]
-            self.config_dict["matrix_authentication_service"]["secret_path"] = f.name
+            self.config_dict["matrix_authentication_service"]["secret_path"] = Path(
+                f.name
+            )
             config = self.parse_config()
             self.assertEqual(config.mas.secret(), "53C237")
 
     def test_secret_path_must_exist(self) -> None:
         del self.config_dict["matrix_authentication_service"]["secret"]
-        self.config_dict["matrix_authentication_service"]["secret_path"] = (
+        self.config_dict["matrix_authentication_service"]["secret_path"] = Path(
             "/not/a/valid/file"
         )
         with self.assertRaises(ConfigError):
