@@ -19,7 +19,7 @@
 #
 #
 
-from typing import Any, Collection, List, Optional, Tuple
+from typing import Any, Collection, Optional
 from unittest.mock import AsyncMock, Mock
 
 from twisted.internet.testing import MemoryReactor
@@ -65,7 +65,7 @@ class TestSpamChecker:
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
         auth_provider_id: Optional[str],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
@@ -76,7 +76,7 @@ class DenyAll(TestSpamChecker):
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
         auth_provider_id: Optional[str],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.DENY
@@ -87,7 +87,7 @@ class BanAll(TestSpamChecker):
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
         auth_provider_id: Optional[str],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.SHADOW_BAN
@@ -98,7 +98,7 @@ class BanBadIdPUser(TestSpamChecker):
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
         auth_provider_id: Optional[str] = None,
     ) -> RegistrationBehaviour:
         # Reject any user coming from CAS and whose username contains profanity
@@ -115,7 +115,7 @@ class TestLegacyRegistrationSpamChecker:
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
 
@@ -125,7 +125,7 @@ class LegacyAllowAll(TestLegacyRegistrationSpamChecker):
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.ALLOW
 
@@ -135,7 +135,7 @@ class LegacyDenyAll(TestLegacyRegistrationSpamChecker):
         self,
         email_threepid: Optional[dict],
         username: Optional[str],
-        request_info: Collection[Tuple[str, str]],
+        request_info: Collection[tuple[str, str]],
     ) -> RegistrationBehaviour:
         return RegistrationBehaviour.DENY
 
@@ -779,7 +779,7 @@ class RegistrationTestCase(unittest.HomeserverTestCase):
         localpart: str,
         displayname: Optional[str],
         password_hash: Optional[str] = None,
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         """Creates a new user if the user does not exist,
         else revokes all previous access tokens and generates a new one.
 
@@ -842,7 +842,7 @@ class RemoteAutoJoinTestCase(unittest.HomeserverTestCase):
 
         async def lookup_room_alias(
             *args: Any, **kwargs: Any
-        ) -> Tuple[RoomID, List[str]]:
+        ) -> tuple[RoomID, list[str]]:
             return RoomID.from_string(self.room_id), ["remotetest"]
 
         self.room_member_handler = Mock(spec=["update_membership", "lookup_room_alias"])
