@@ -18,7 +18,7 @@
 # [This file includes modifications made by New Vector Limited]
 #
 #
-from typing import List, Optional, Tuple
+from typing import Optional
 from unittest.mock import AsyncMock, Mock
 
 from twisted.internet.testing import MemoryReactor
@@ -156,7 +156,7 @@ class HTTPPusherTests(HomeserverTestCase):
 
     def _request_notifications(
         self, from_token: Optional[str], limit: int, expected_count: int
-    ) -> Tuple[List[str], str]:
+    ) -> tuple[list[str], str]:
         """
         Make a request to /notifications to get the latest events to be notified about.
 
