@@ -19,7 +19,7 @@
 #
 #
 
-from typing import Optional, Tuple
+from typing import Optional
 
 from twisted.internet.testing import MemoryReactor
 
@@ -47,7 +47,7 @@ class EventPushActionsStoreTestCase(HomeserverTestCase):
         assert persist_events_store is not None
         self.persist_events_store = persist_events_store
 
-    def _create_users_and_room(self) -> Tuple[str, str, str, str, str]:
+    def _create_users_and_room(self) -> tuple[str, str, str, str, str]:
         """
         Creates two users and a shared room.
 
